==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/test/functional/cmdline_options_testresources/src/j9vm/test/sigxfsz/SignalXfszTest.java <==
package j9vm.test.sigxfsz;

/*******************************************************************************
 * Copyright (c) 2013, 2018 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

import static java.lang.System.*;
import java.io.*;

public class SignalXfszTest {

	public static void main(String[] args) throws IOException {
		System.out.println("Starting SignalXfszTest");
		if (1 == args.length) {
			File file = new File(args[0]);
			FileOutputStream fos = null;
			try {
				fos = new FileOutputStream(file);
				for (int i = 0; i < 204900; i++) {
					fos.write(new byte[10000]);
				}
				out.println("File is written successfully");
			} catch (Throwable e) {
				System.err.println("Failed to write the file: " + args[0]);
				e.printStackTrace();
			} finally {
				fos.close();
				file.delete();
			}
		} else {
			System.err.println("Usage:  SignalXfszTest <path of the file to be written out>");
			System.exit(-1);
		}
	}
}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/test/functional/cmdline_options_testresources/src/j9vm/test/sigxfsz/SignalXfszTest.java <==
package j9vm.test.sigxfsz;

/*
 * Copyright IBM Corp. and others 2013
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */

import static java.lang.System.*;
import java.io.*;

public class SignalXfszTest {

	public static void main(String[] args) throws IOException {
		System.out.println("Starting SignalXfszTest");
		if (1 == args.length) {
			File file = new File(args[0]);
			FileOutputStream fos = null;
			try {
				fos = new FileOutputStream(file);
				for (int i = 0; i < 204900; i++) {
					fos.write(new byte[10000]);
				}
				out.println("File is written successfully");
			} catch (Throwable e) {
				System.err.println("Failed to write the file: " + args[0]);
				e.printStackTrace();
			} finally {
				fos.close();
				file.delete();
			}
		} else {
			System.err.println("Usage:  SignalXfszTest <path of the file to be written out>");
			System.exit(-1);
		}
	}
}
